@@ -12,19 +12,17 @@ HTML::Tidy - Web validation in a Perl object
 
 =head1 VERSION
 
-Version 1.04
-
-    $Header: /home/cvs/html-tidy/lib/HTML/Tidy.pm,v 1.37 2004/05/12 20:18:54 andy Exp $
+Version 1.06
 
 =cut
 
-our $VERSION = "1.04";
+our $VERSION = "1.06";
 
 =head1 SYNOPSIS
 
     use HTML::Tidy;
 
-    my $tidy = new HTML::Tidy;
+    my $tidy = HTML::Tidy->new( {config_file => 'path/to/config'} );
     $tidy->ignore( type => TIDY_WARNING );
     $tidy->parse( "foo.html", $contents_of_foo );
 
@@ -36,7 +34,7 @@ our $VERSION = "1.04";
 
 C<HTML::Tidy> is an HTML checker in a handy dandy object.  It's meant as
 a replacement for L<HTML::Lint>.  If you're currently an L<HTML::Lint>
-user looking to migrate, see the section L<Converting from HTML::Lint>.
+user looking to migrate, see the section L</Converting from HTML::Lint>.
 
 =head1 Exports
 
@@ -63,18 +61,31 @@ Create an HTML::Lint object.
 
     my $tidy = HTML::Tidy->new();
 
+Optionally you can give a hashref of configuration parms.  Currently,
+only C<config_file> is supported.
+
+    my $tidy = HTML::Tidy->new( {config_file => 'path/to/tidy.cfg'} );
+
+This configuration file will be read and used when you clean an HTML file.
+
 =cut
 
 sub new {
     my $class = shift;
+    my $args = shift || {};
 
-    my $self = {
+    my $self = bless {
         messages => [],
         ignore_type => [],
         ignore_text => [],
-    };
+        config_file => "",
+    }, $class;
 
-    bless $self, $class;
+    for my $key ( qw( config_file ) ) {
+        if ( exists $args->{$key} ) {
+            $self->{$key} = $args->{$key};
+        }
+    }
 
     return $self;
 }
@@ -167,13 +178,23 @@ sub parse {
     my $self = shift;
     my $filename = shift;
 
-    my $parse_errors;
     my $html = join( "", @_ );
 
     my $errorblock = _tidy_messages( $html );
     return unless defined $errorblock;
 
-    my @lines = split( /\012/, $errorblock );
+
+    return !$self->_parse_errors($filename, $errorblock);
+}
+
+sub _parse_errors {
+    my $self = shift;
+    my $filename = shift;
+    my $errs = shift;
+
+    my $parse_errors;
+
+    my @lines = split( /\012/, $errs );
     for my $line ( @lines ) {
         chomp $line;
 
@@ -182,20 +203,38 @@ sub parse {
             my $type = ($3 eq "Warning") ? TIDY_WARNING : TIDY_ERROR;
             $message = HTML::Tidy::Message->new( $filename, $type, $1, $2, $4 );
 
-        } elsif ( $line =~ /^\d+ warnings?, \d+ errors? were found!/ ) {
+        }
+        elsif ( $line =~ /^\d+ warnings?, \d+ errors? were found!/ ) {
             # Summary line we don't want
 
-        } elsif ( $line eq "No warnings or errors were found." ) {
+        }
+        elsif ( $line eq "No warnings or errors were found." ) {
             # Summary line we don't want
 
-        } else {
+        }
+        elsif ( $line eq "This document has errors that must be fixed before" ){
+            # Summary line we don't want
+
+        }
+        elsif ( $line eq "using HTML Tidy to generate a tidied up version." ){
+            # Summary line we don't want
+
+        }
+        elsif ( $line =~ m/^Info:/  ) {
+            # Info line we don't want
+
+        }
+        elsif ( $line =~ m/^\s*$/  ) {
+            # Blank line we don't want
+
+        }
+        else {
             warn "Unknown error type: $line";
             ++$parse_errors;
         }
-        push( @{$self->{messages}}, $message ) if $self->_is_keeper( $message );
-    }
-
-    return !$parse_errors;
+        push( @{$self->{messages}}, $message ) if $message && $self->_is_keeper( $message );
+    } # for
+    return $parse_errors;
 }
 
 =head2 clean( $str [, $str...] )
@@ -209,7 +248,15 @@ tidy, or parsing tidy's output.
 
 sub clean {
     my $self = shift;
-    return _tidy_clean(join( "", @_ ));
+
+    my $text = join( "", @_ );
+    if ( defined $text ) {
+        $text .= "\n";
+    }
+    my ($cleaned, $errbuf) = _tidy_clean( $text, $self->{config_file} );
+
+    $self->_parse_errors('', $errbuf);
+    return $cleaned;
 }
 
 
@@ -269,16 +316,16 @@ prerequisite modules.
 =head1 Bugs & Feedback
 
 I welcome your comments and suggestions.  Please send them to
-C<< <bug-html-tidy@rt.cpan.org> >> so that they can be tracked in the
+C<< <bug-html-tidy at rt.cpan.org> >> so that they can be tracked in the
 RT ticket tracking system.
 
 =head1 Author
 
-Andy Lester, C<< <andy@petdance.com> >>
+Andy Lester, C<< <andy at petdance.com> >>
 
 =head1 Copyright & License
 
-Copyright (C) 2004 by Andy Lester
+Copyright (C) 2005 by Andy Lester
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.1 or,
